Lua_VideoItem = class("Lua_VideoItem", Lua_ListCell);
function Lua_VideoItem:ctor(p)
    self:superCall("ctor", p, "VideoItem_skin");
end

function Lua_VideoItem:buildShowItem()
    self:superCall("buildShowItem");

    self.leftAvatar = Lua_AvatarItem.new(self.showObject);
    self.leftAvatar:setLocation(-324.5, 157.5, 0);
    self.leftAvatar:setScale(0.6, 0.6, 0.6);
    self.leftAvatar:setCanClick(true);

    self.rightAvatar = Lua_AvatarItem.new(self.showObject);
    self.rightAvatar:setLocation(324.5, 157.5, 0);
    self.rightAvatar:setScale(0.6, 0.6, 0.6);
    self.rightAvatar:setCanClick(true);

    self.leftForce = Lua_NumberImage.new(self.showObject);
    self.leftForce:setLocation(-283.8, 135, 0);
    self.leftForce.pivot = 1;
    self.leftForce.scaleVal = 0.8;
    self.leftForce.numOffsetX = -2;
    self.leftForce.numAtlas = "number";
    self.leftForce.firstStr = "xui_zl1_number_10";
    self.leftForce.preStr = "xui_zl1_number_0";

    self.rightForce = Lua_NumberImage.new(self.showObject);
    self.rightForce:setLocation(283.8, 135, 0);
    self.rightForce.pivot = -1;
    self.rightForce.scaleVal = 0.8;
    self.rightForce.numOffsetX = -2;
    self.rightForce.numAtlas = "number";
    self.rightForce.firstStr = "xui_zl1_number_10";
    self.rightForce.preStr = "xui_zl1_number_0";

    self.leftPanel = Lua_HeroGridViewPanel.new(self.showObject);
    self.leftPanel:setLocation(-236.5, 9, 0);
    self.leftPanel:setGridCell(65, 65, Lua_VideoHeroGridItem);
    self.leftPanel:setCanClick(false)

    self.rightPanel = Lua_HeroGridViewPanel.new(self.showObject);
    self.rightPanel:setLocation(236.5, 9, 0);
    self.rightPanel:setGridCell(65, 65, Lua_VideoHeroGridItem);
    self.rightPanel:setCanClick(false)

    self.checkFight:addClickFuntion(self, self.onCheckFight);
    self.btnShare:addClickFuntion(self, self.onShare);
    self.btnChekData:addClickFuntion(self, self.onChekData);
    self.btnCollect:addClickFuntion(self, self.onCollect);
    self.btnLike:addClickFuntion(self, self.onLike);

    self.channelBg.clickScale = false;
    self.channelBg:addClickFuntion(self, self.onCancelShare);
    self.world:addClickFuntion(self, self.onWorld);
    self.alliance:addClickFuntion(self, self.onAlliance);
    self.shareMask.clickScale = false;
    self.shareMask.clickSound = nil;
    self.shareMask:addClickFuntion(self, self.onCancelShare);
end

function Lua_VideoItem:dispose()
    if self.leftAvatar ~= nil then
        self.leftAvatar:dispose();
        self.leftAvatar = nil;
    end
    if self.rightAvatar ~= nil then
        self.rightAvatar:dispose();
        self.rightAvatar = nil;
    end
    if self.leftForce ~= nil then
        self.leftForce:dispose();
        self.leftForce = nil;
    end
    if self.rightForce ~= nil then
        self.rightForce:dispose();
        self.rightForce = nil;
    end
    if self.leftPanel ~= nil then
        self.leftPanel:dispose();
        self.leftPanel = nil;
    end
    if self.rightPanel ~= nil then
        self.rightPanel:dispose();
        self.rightPanel = nil;
    end
    if self.redPoint then
        self.redPoint:dispose();
        self.redPoint = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_VideoItem:setData(data)
    self.data = data;
    self.shareObject:SetActive(false);
    self.shareMask:setEnable(false);

    local role = data.a_role.show_role;
    if DataCenter.roleData:isSameServer(role.server_prev) or data.a_role.is_robot == 1 then
        self.left_name.text = role.name;
    else
        self.left_name.text = LanUtil.formateStr(10051, role.server_prev, role.name);
    end

    self.leftAvatar:setRoleId(role.id, role.server_flag, data.a_role.is_robot);
    self.leftAvatar:setRoleDressUp(role.dress_info);
    self.leftAvatar:setRoleLevel(role.level);

    local lineup = data.a_role.lineup;
    self.leftForce.num = lineup.force;
    -- self.leftPanel:setRoleId(role.id, role.server_flag, data.a_role.is_robot)
    self.leftPanel:setParams(self.data.index, self.data.record_id);
    self.leftPanel:setDataByProto(lineup.hero_list);

    role = data.d_role.show_role;
    if DataCenter.roleData:isSameServer(role.server_prev) or data.d_role.is_robot == 1 then
        self.right_name.text = role.name;
    else
        self.right_name.text = LanUtil.formateStr(10051, role.server_prev, role.name);
    end

    self.rightAvatar:setRoleId(role.id, role.server_flag, data.d_role.is_robot);
    self.rightAvatar:setRoleDressUp(role.dress_info);
    self.rightAvatar:setRoleLevel(role.level);

    lineup = data.d_role.lineup;
    self.rightForce.num = lineup.force;
    -- self.rightPanel:setRoleId(role.id, role.server_flag, data.d_role.is_robot)
    self.rightPanel:setParams(self.data.index, self.data.record_id);
    self.rightPanel:setDataByProto(lineup.hero_list);

    if data.is_win == 1 then
        self.left_result:setAltas("common_altas_4", "xui_jys_label_1");
        self.right_result:setAltas("common_altas_4", "xui_jys_label_2");
    else
        self.left_result:setAltas("common_altas_4", "xui_jys_label_2");
        self.right_result:setAltas("common_altas_4", "xui_jys_label_1");
    end

    self.timeText.text = Lua_TimeTransform.transSeconds8(data.times);
    if data.fight_scene > 0 then
        local config = Lua_FightTemplateConfigData.getConfigData(data.fight_scene);
        if config then
            self.stageText.text = config.title
        else
            self.stageText.text = nil;
        end
    else
        self.stageText.text = nil;
    end

    self.playNum.text = data.replay_times;
    self.shareNum.text = data.send_times;
    self.likeNum.text = data.like_times;
    if data.is_liked == 0 then
        self.btnLike.mouseEnable = true;
        self.btnLike:setAltas("video_atlas", "xui_lxg_button_2");
    else
        self.btnLike.mouseEnable = false;
        self.btnLike:setAltas("video_atlas", "xui_lxg_button_7");
    end
    if data.is_saved == 0 then
        self.btnCollect:setAltas("video_atlas", "xui_lxg_button_3");
    else
        self.btnCollect:setAltas("video_atlas", "xui_lxg_button_1");
    end

    self:checkRedPoint();
end

function Lua_VideoItem:checkRedPoint()
    if self.data.is_liked == 0 and (self.data.index == 3 or self.data.index == 7) then
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Video);
            self.redPoint:setLocation(330, -132, 0);
        end
        self.redPoint:setEnable(true);
    else
        if self.redPoint then
            self.redPoint:setEnable(false);
        end
    end
end

function Lua_VideoItem:onCheckFight(go)
    if self.data == nil then
        return;
    end
    if self.clickTime and getTime() - self.clickTime < 1 then
        OperateAlert.showLangValue(10031);
        return;
    end
    self.clickTime = getTime();

    if self.data.fight_scene == 1014 then
        Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.data.record_id, Lua_FightDefine.REPLAY_VIDEO, nil, nil, 12);
    else
        Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.data.record_id, Lua_FightDefine.REPLAY_VIDEO);
    end
end

function Lua_VideoItem:onShare(go)
    if self.data == nil then
        return;
    end
    self.shareObject:SetActive(true);
    self.shareMask:setEnable(true);
end

function Lua_VideoItem:onChekData(go)
    if self.data == nil then
        return;
    end
    Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightHurtCollect(self.data.record_id);
end

function Lua_VideoItem:onCollect(go)
    if self.data == nil then
        return;
    end

    if self.data.is_saved == 1 then
        Lua_ProxyManager.getProxy("Lua_VideosProxy"):sHandle(4, self.data.record_id);
    else
        local save_times = DataCenter.videosData.save_times;
        local collect_limit = DataCenter.videosUtil.self_save_limit;
        if save_times >= collect_limit then
            OperateAlert.showLangValue(480004);
        else
            Lua_ProxyManager.getProxy("Lua_VideosProxy"):sHandle(1, self.data.record_id);
        end
    end
end

function Lua_VideoItem:onLike(go)
    if self.data == nil then
        return;
    end

    local like_times = DataCenter.videosData.like_times;
    local like_limit = DataCenter.videosUtil.like_times
    if like_times >= like_limit then
        OperateAlert.showLangValue(480005);
    else
        Lua_ProxyManager.getProxy("Lua_VideosProxy"):sHandle(2, self.data.record_id);
    end
end

function Lua_VideoItem:onCancelShare(go)
    self.shareObject:SetActive(false);
    self.shareMask:setEnable(false);
end

function Lua_VideoItem:onWorld(go)
    self:sendChat(Lua_ChatData.CHANNEL_WORLD);
    self.shareObject:SetActive(false);
    self.shareMask:setEnable(false);
end

function Lua_VideoItem:onAlliance(go)
    if not DataCenter.roleData:isJoinTheLeague() then
        OperateAlert.showLangValue(480010);
        return
    end
    self:sendChat(Lua_ChatData.CHANNEL_LEAGUE);
    self.shareObject:SetActive(false);
    self.shareMask:setEnable(false);
end

function Lua_VideoItem:sendChat(channel)
    local configInfo = DataCenter.videosUtil:getVideoConfig(self.data.index);
    local str = LanUtil.formateStr(configInfo.share_str, self.data.a_role.show_role.name, self.data.d_role.show_role.name);
    DataCenter.chatData:setChatShowItem(Lua_ChatData.CONTENT_FIGHT_VIDEO, self.data.record_id);
    Lua_ChatUtil.sendMsg(channel, str, false, true);
end




















Lua_VideoHeroGridItem = class("Lua_VideoHeroGridItem", Lua_HeroGridViewItem)
function Lua_VideoHeroGridItem:buildShowItem()
    self:superCall("buildShowItem")

    self.bg:setAltas("common_altas_4", "xui_jys_widget_7")
    self.bg:resetSize()
    self.bg:setScale(0.5, 0.5, 1)
end

function Lua_VideoHeroGridItem:setParams(param1, param2)
    self.index = param1;
    self.recordId = param2;
end

function Lua_VideoHeroGridItem:setData(dataType, data)
    self:superCall("setData", dataType, data);
    if self.itemIcon then
        self.itemIcon:setScale(0.5, 0.5, 1);
    end
end

function Lua_VideoHeroGridItem:onIconClick()
    if self.data == nil then
        return;
    end

    if self.isRobot == 1 then
        OperateAlert.showLangValue(126323)
        return
    end

    Lua_ProxyManager.getProxy("Lua_VideosProxy"):sCheckHeroInfo(self.recordId, self.data.unique_id, self.index);
end